@@ -254,21 +254,6 @@ def vv_integral(T: float, deg: int, idata: np.ndarray, molecule1: MoleculeSTS, m
 def vv_collisions(T: float, T1_1: float, T1_2: float, idata: np.ndarray, molecule1: Molecule, molecule2: Molecule,
                   nokt: bool=False) -> np.ndarray:
     """Calculates the averaging :math:`\\left<F \\right>^{VV}_{cd}` over all one-quantum VV crosssections of the type
-    M1(i) + M2(k) -> M1(i + i_delta) + M2(k - i_delta) (using the FHO probability and VSS crosssection)
-    of the following quantities:
-        0. :math:`\\left(\\Delta \\mathcal{E}^{vibr}_{c}\\right)^{2}`
-        #. :math:`\\left(\\Delta \\mathcal{E}^{vibr}_{d}\\right)^{2}`
-        #. :math:`\\Delta \\mathcal{E}^{vibr}_{c} \\mathcal{E}^{vibr}_{d}`
-        #. :math:`\\Delta i \\Delta \\mathcal{E}^{vibr}_{c}`
-        #. :math:`\\Delta i \\Delta \\mathcal{E}^{vibr}_{d}`
-        #. :math:`\\Delta k \\Delta \\mathcal{E}^{vibr}_{c}`
-        #. :math:`\\Delta k \\Delta \\mathcal{E}^{vibr}_{d}`
-        #. :math:`\\Delta \\mathcal{E}^{vibr}_{c}`
-        #. :math:`\\Delta \\mathcal{E}^{vibr}_{d}`
-        #. :math:`\\left(\\Delta i \\right)^{2}`
-        #. :math:`\\left(\\Delta k \\right)^{2}`
-        #. :math:`\\Delta i \\Delta k`
-        #. :math:`\\Delta i`
 
     Parameters
     ----------
@@ -426,7 +411,7 @@ def dE_rot_c_dE_rot_d(T: float, idata: np.ndarray, molecule1: MoleculeSTS, molec
     """Calculates either the partial averaging of the squared change in rotational energy
     :math:`\\left<\\Delta \\mathcal{E}^{rot}_{c}\\Delta \\mathcal{E}^{rot}_{d}\\right>_{part}`
     or the full averaging of the same quantity
-    `\\left<\\Delta \\mathcal{E}^{rot}_{c}\\Delta \\mathcal{E}^{rot}_{d}\\right>`
+    :math:`\\left<\\Delta \\mathcal{E}^{rot}_{c}\\Delta \\mathcal{E}^{rot}_{d}\\right>`
 
     Parameters
     ----------
